@@ -12,9 +12,7 @@ pub fn proxy_request(request: &Request, target: SocketAddr, timeout: Duration) -
     match proxy_request_internal(request, target, timeout) {
         Ok(response) => response,
         Err(_) => Response::empty(StatusCode::BadGateway)
-            .with_bytes(b"<html><body><h1>502 Bad Gateway</h1></body></html>")
-            .with_request_compatibility(request)
-            .with_generated_headers(),
+            .with_bytes(b"<html><body><h1>502 Bad Gateway</h1></body></html>"),
     }
 }
 
